import {
  select,csv,scaleLinear,scaleTime,extent,max,axisLeft,axisBottom,area,curveBasis,format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
//displaying the title
const render = data => {
  const title = 'USA Restaurants over years';
  //x-paxix label
  const xValue = d => d.Year;
  const xAxisLabel = 'Years';
  //y-axis label
  const y1Value = d => d.count_of_Restarants;
  const y2Value=d=>d.NOx;
  const circleRadius = 6;
  const yAxisLabel = 'Total Number of Restaurants in USA';
  //styles of chart
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain([0, max(data, y1Value)])
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .ticks(6)
    .tickSize(-innerHeight)
    .tickPadding(15);

  const yAxisTickFormat = number =>
    format('.1s')(number)
      .replace('G', 'B');
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
    .tickFormat(yAxisTickFormat);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  //area graph generator
  const areaGenerator = area()
    .x(d => xScale(xValue(d)))
    .y0(innerHeight)
    .y1(d => yScale(y1Value(d)))
    .curve(curveBasis);
  // Area graph generator for the second area
   const areaGenerator2 = area()
    .x(d => xScale(xValue(d)))
    .y0(innerHeight)
    .y1(d => yScale(y2Value(d)))
    .curve(curveBasis);
  
  g.append('path')
      .attr('class', 'line-path1')
      .attr('d', areaGenerator(data));
  
  g.append('path')
      .attr('class', 'line-path2')
      .attr('d', areaGenerator2(data));
  
  svg.append('text')
      .attr('class', 'title')
      .attr('x', width / 2)
      .attr('y', 45)
      .text(title);
};
// gist of dataset linked
csv('https://gist.githubusercontent.com/maheganesh/aeb7a95e040e12dbbae73be4a4f962c6/raw/49a2a5e8e40099160115efd84dec8e52e30b21fa/Restaurant%2520count%2520line.csv')
  .then(data => {
    data.forEach(d => {
      d.count_of_Restarants = +d.count_of_Restarants;
      d.Year = new Date(d.Year);
    });
    render(data);
  });